@@ -2,7 +2,6 @@ from typing import cast, Union
 
 from .structs import Result, Start
 
-from .errors import GeneratorAlreadyExhausted, GeneratorAlreadyExhaustedError
 from .types import TurboGenWrapper
 
 __all__ = [
@@ -18,25 +17,24 @@ async def run(
 
     # Set placeholder values
     done = False
-    output = GeneratorAlreadyExhausted()
+    output = Result(content=None)
+    run_count = 0
 
     # Run generator
     try:
         while output := await gen.asend(input):
+            run_count += 1
+
             if isinstance(output, Start):
                 continue
 
-            if output.needs_input:
+            if output.needs_input or output.original_role == "assistant":
                 break
 
     # Generator exhausted, mark done
     except StopAsyncIteration:
         done = True
 
-    # Output is still placeholder? Raise error
-    if isinstance(output, GeneratorAlreadyExhausted):
-        raise GeneratorAlreadyExhaustedError()
-
     # Set result values
     result = cast(Result, output)
     result.done = done
